/*********************************************************************************
   mando_airsupportdlg.sqf v1.4
   by Mandoble, April 2008

   Creates and handles the air support console. From this console you may order bomb runs against selected position in the map, or close air support missions where the planes will engange any not friendly vehicle, ship or static weapon within a range of 500m around the marked center.


   This script doesnt require parameters, you may execute it as action menu, from a trigger, etc.
   This script requires mando_bombs.sqf, mando_bombs_sadarm.sqf and mando_bombs_effects.sqf.
   This script requires mando_airsupportdlg.h, include it in your description.ext file (#include "mando_airsupportdlg.h").

   This script uses the following set of global variables:
   mando_support_left_WEST: Maximum number of west planes available for bomb run or cas missions (default value is 8).
   mando_support_left_EAST: Maximum number of east planes available for bomb run or cas missions (default value is 8).
   mando_support_left_GUER: Maximum number of res planes available for bomb run or cas missions (default value is 8).
   mando_support_left_CIV: Maximum number of civ planes available for bomb run or cas missions (default value is 8).
   mando_support_left_ca_WEST: Maximum number of west chopper attacks (default value is 8).
   mando_support_left_ca_EAST: Maximum number of east chopper attacks (default value is 8).
   mando_support_left_ca_GUER: Maximum number of res chopper attacks (default value is 8).
   mando_support_left_ca_CIV: Maximum number of civ chopper attacks (default value is 8).
   mando_support_left_pa_WEST: Maximum number of west airborne chopper assaults (default value is 8).
   mando_support_left_pa_EAST: Maximum number of east airborne chopper assaults  (default value is 8).
   mando_support_left_pa_GUER: Maximum number of res airborne chopper assaults  (default value is 8).
   mando_support_left_pa_CIV: Maximum number of civ airborne chopper assaults  (default value is 8).
   mando_support_left_cm_WEST: Maximum number of west cruise missile attacks (default value is 8).
   mando_support_left_cm_EAST: Maximum number of east cruise missile attacks (default value is 8).
   mando_support_left_cm_GUER: Maximum number of res cruise missile attacks (default value is 8).
   mando_support_left_cm_CIV: Maximum number of civ cruise missile attacks (default value is 8).
   mando_support_left_rc_WEST: Maximum number of west reconnaissance missions (default value is 8).
   mando_support_left_rc_EAST: Maximum number of east reconnaissance missions (default value is 8).
   mando_support_left_rc_GUER: Maximum number of res reconnaissance missions (default value is 8).
   mando_support_left_rc_CIV: Maximum number of civ reconnaissance missions (default value is 8).
   mando_support_left_am_WEST: Maximum number of west ammo supply missions (default value is 8).
   mando_support_left_am_EAST: Maximum number of east ammo supply missions (default value is 8).
   mando_support_left_am_GUER: Maximum number of res ammo supply missions (default value is 8).
   mando_support_left_am_CIV: Maximum number of civ ammo supply missions (default value is 8).
   mando_support_left_ve_WEST: Maximum number of west vehicle supply missions (default value is 8).
   mando_support_left_ve_EAST: Maximum number of east vehicle supply missions (default value is 8).
   mando_support_left_ve_GUER: Maximum number of res vehicle supply missions (default value is 8).
   mando_support_left_ve_CIV: Maximum number of civ vehicle supply missions (default value is 8).
   mando_support_left_re_WEST: Maximum number of west reinforcement missions (default value is 8).
   mando_support_left_re_EAST: Maximum number of east reinforcement missions (default value is 8).
   mando_support_left_re_GUER: Maximum number of res reinforcement missions (default value is 8).
   mando_support_left_re_CIV: Maximum number of civ reinforcement missions (default value is 8).
   mando_support_left_cp_WEST: Maximum number of west CAP missions (default value is 8).
   mando_support_left_cp_EAST: Maximum number of east CAP missions (default value is 8).
   mando_support_left_cp_GUER: Maximum number of res CAP missions (default value is 8).
   mando_support_left_cp_CIV: Maximum number of civ CAP missions (default value is 8).


   mando_airsupport_type: type of plane for the missions (default value is "AV8B2" for west and "Su34B" for east).
   mando_airsupport_type_ca: type of chopper for chopper attack missions (default value is "AH1W" for west and "KA50" for east).
   mando_airsupport_type_pa: type of chopper for airborne assault missions (default value is "UH60MG" for west and "Mi17_MG" for east).
   mando_airsupport_type_rc: type of plane or chopper for reconnaissance missions (default is "AV8B" for west and "Su34" for east).
   mando_airsupport_type_am: type of chopper for ammo supply missions (default value is "UH60MG" for west and "Mi17_MG" for east).
   mando_airsupport_type_ambox: ammo box type to be used in ammo supply missions, default is "WeaponBoxWest" for west, etc.

   mando_airsupport_type_ve: type of chopper for vehicle supply missions (default value is "UH60MG" for west and "Mi17_MG" for east).
   mando_airsupport_type_vehicle: vehicle type to be used in vehicle supply missions, default is "Truck5t" for west, etc.
   mando_support_infantrytype: Array defining 10 soldier classes for airborne assaults and reinforcements missions.
   mando_airsupport_type_cp: type of plane or chopper for CAP missions (default is "AV8B" for west and "Su34" for east).

   mando_airsupport_range: Range from target where the planes will be spawned (default and minimum value is 3500).
   mando_airsupport_max_cas: In close air support, maximum number of attacks per plane (default value is 2).
   mando_airsupport_bomb_type: The class of a bomb type ammo or the special type "SADARM". "Bo_GBU12_LGB" is used by default.
   mando_airsupport_bomb_alt: The base flying altitude for the bomb runs in m, default value is 150.
   mando_airsupport_bomb_pos: Model coords position of a bomb spawned relative to the plane (the second bomb will be spawned at the opposite side). [2, 0, -2] by default.
   mando_airsupport_cmissile: Cruise missile launcher (requires mando missile initialized), default value is objNull;
   mando_airsupport_cmissile_pos = Model coordinates of the cruise missile launch position.

   The following variables set to true disable corresponding buttons
   mando_support_no_cas: Disables Close Air Support button.
   mando_support_no_br: Disables Bomb run button.
   mando_support_no_ff: Disables Free fall bombs button.
   mando_support_no_sa: Disables SADARM button.
   mando_support_no_gs: Disables Gunships Support button.
   mando_support_no_ab: Disables Airborne assault button.
   mando_support_no_cm: Disables Cruise missile attack button.
   mando_support_no_rc: Disables reconnaissance button.
   mando_support_no_am: Disables ammo supply button.
   mando_support_no_re: Disables Airborne reinforcements button.
   mando_support_no_cp: Disables Combat Air Patrol button.


   Before executing this script you may set the desired values for the previous variables, if you dont, default values will be used.

   Example:
   player addAction ["Air Support console", "mando_airsupportdlg.sqf"];

   or
  
   []execVM"mando_airsupportdlg.sqf";

*********************************************************************************/


private ["_event", "_params", "_display", "_i", "_nplanes", "_left", "_first", "_reco"];

_first = false;
_reco  = false;
if (count _this == 0) then
{
   _first = true;
}
else
{
   if (typeName (_this select 0) != "STRING") then
   {
      if (typeName (_this select 0) == "BOOL") then
      {
         _reco = true;
      }
      else
      {
         _first = true;
      };
   }
   else
   {      
      _event = _this select 0;
      _params = _this select 1;
   };
};


if (_reco) exitWith
{
   if (isNil "mando_reco_monitor") then
   {
      mando_reco_monitor = true;
      mando_reco_base = 0;
      mando_reco_num = 0;
      mando_reco_side = west;
      []spawn
      {
         private["_num", "_side", "_base"];
         while {true} do
         {
            waitUntil {mando_reco_num != 0};
            _num = mando_reco_num;
            _side = mando_reco_side;
            _base = mando_reco_base; 
            mando_reco_num = 0;

            if (side player == _side) then
            {
               [_num, _side, _base] spawn
               {
                  private["_num", "_side", "_base", "_i", "_marker", "_pos", "_text"];
                  _num = _this select 0;
                  _side = _this select 1; 
                  _base = _this select 2;
                  [_side, "HQ"] sideChat "Receiving reconnaissance info";
                  for [{_i=0},{_i != _num},{_i = _i + 1}] do
                  {
                     _pos = markerPos format["mk_mando_rct_%1", _i + _base];
                     _text = markerText format["mk_mando_rct_%1", _i + _base];
                     _marker = createMarkerLocal [format["mk_mando_rctr_%1", _i + _base], _pos];
                     format["mk_mando_rctr_%1", _i + _base] setMarkerTypeLocal "Dot";
                     format["mk_mando_rctr_%1", _i + _base] setMarkerColorLocal "ColorWhite";
                     format["mk_mando_rctr_%1", _i + _base] setMarkerSizeLocal [0.25, 0.25];
                     format["mk_mando_rctr_%1", _i + _base] setMarkerTextLocal _text;
                     Sleep 0.25;
                  };
                  Sleep 120;
                  for [{_i=0},{_i != _num},{_i = _i + 1}] do
                  {
                     deleteMarkerLocal format["mk_mando_rctr_%1", _i + _base];
                  };               
               };
            };
 
         };
      };
   };
};


if (_first) exitWith
{
   if (isNil "mando_support_left_WEST") then
   {
      mando_support_left_WEST = 8;
   };

   if (isNil "mando_support_left_EAST") then
   {
      mando_support_left_EAST = 8;
   };

   if (isNil "mando_support_left_GUER") then
   {
      mando_support_left_GUER = 8;
   };

   if (isNil "mando_support_left_CIV") then
   {
      mando_support_left_CIV = 8;
   };

   if (isNil "mando_support_left_ca_WEST") then
   {
      mando_support_left_ca_WEST = 8;
   };

   if (isNil "mando_support_left_ca_EAST") then
   {
      mando_support_left_ca_EAST = 8;
   };

   if (isNil "mando_support_left_ca_GUER") then
   {
      mando_support_left_ca_GUER = 8;
   };

   if (isNil "mando_support_left_ca_CIV") then
   {
      mando_support_left_ca_CIV = 8;
   };

   if (isNil "mando_support_left_pa_WEST") then
   {
      mando_support_left_pa_WEST = 8;
   };

   if (isNil "mando_support_left_pa_EAST") then
   {
      mando_support_left_pa_EAST = 8;
   };

   if (isNil "mando_support_left_pa_GUER") then
   {
      mando_support_left_pa_GUER = 8;
   };

   if (isNil "mando_support_left_pa_CIV") then
   {
      mando_support_left_pa_CIV = 8;
   };

   if (isNil "mando_support_left_cm_WEST") then
   {
      mando_support_left_cm_WEST = 8;
   };

   if (isNil "mando_support_left_cm_EAST") then
   {
      mando_support_left_cm_EAST = 8;
   };

   if (isNil "mando_support_left_cm_GUER") then
   {
      mando_support_left_cm_GUER = 8;
   };

   if (isNil "mando_support_left_cm_CIV") then
   {
      mando_support_left_cm_CIV = 8;
   };

   if (isNil "mando_support_left_rc_WEST") then
   {
      mando_support_left_rc_WEST = 8;
   };

   if (isNil "mando_support_left_rc_EAST") then
   {
      mando_support_left_rc_EAST = 8;
   };

   if (isNil "mando_support_left_rc_GUER") then
   {
      mando_support_left_rc_GUER = 8;
   };

   if (isNil "mando_support_left_rc_CIV") then
   {
      mando_support_left_rc_CIV = 8;
   };

   if (isNil "mando_support_left_am_WEST") then
   {
      mando_support_left_am_WEST = 8;
   };

   if (isNil "mando_support_left_am_EAST") then
   {
      mando_support_left_am_EAST = 8;
   };

   if (isNil "mando_support_left_am_GUER") then
   {
      mando_support_left_am_GUER = 8;
   };

   if (isNil "mando_support_left_am_CIV") then
   {
      mando_support_left_am_CIV = 8;
   };

   if (isNil "mando_support_left_ve_WEST") then
   {
      mando_support_left_ve_WEST = 8;
   };

   if (isNil "mando_support_left_ve_EAST") then
   {
      mando_support_left_ve_EAST = 8;
   };

   if (isNil "mando_support_left_ve_GUER") then
   {
      mando_support_left_ve_GUER = 8;
   };

   if (isNil "mando_support_left_ve_CIV") then
   {
      mando_support_left_ve_CIV = 8;
   };

   if (isNil "mando_support_left_re_WEST") then
   {
      mando_support_left_re_WEST = 8;
   };

   if (isNil "mando_support_left_re_EAST") then
   {
      mando_support_left_re_EAST = 8;
   };

   if (isNil "mando_support_left_re_GUER") then
   {
      mando_support_left_re_GUER = 8;
   };

   if (isNil "mando_support_left_re_CIV") then
   {
      mando_support_left_re_CIV = 8;
   };

   if (isNil "mando_support_left_cp_WEST") then
   {
      mando_support_left_cp_WEST = 8;
   };

   if (isNil "mando_support_left_cp_EAST") then
   {
      mando_support_left_cp_EAST = 8;
   };

   if (isNil "mando_support_left_cp_GUER") then
   {
      mando_support_left_cp_GUER = 8;
   };

   if (isNil "mando_support_left_cp_CIV") then
   {
      mando_support_left_cp_CIV = 8;
   };


   {publicVariable _x} forEach ["mando_support_left_WEST", "mando_support_left_EAST","mando_support_left_GUER","mando_support_left_CIV","mando_support_left_ca_WEST", "mando_support_left_ca_EAST","mando_support_left_ca_GUER","mando_support_left_ca_CIV","mando_support_left_pa_WEST", "mando_support_left_pa_EAST","mando_support_left_pa_GUER","mando_support_left_pa_CIV","mando_support_left_cm_WEST", "mando_support_left_cm_EAST","mando_support_left_cm_GUER","mando_support_left_cm_CIV","mando_support_left_rc_WEST", "mando_support_left_rc_EAST","mando_support_left_rc_GUER","mando_support_left_rc_CIV","mando_support_left_am_WEST", "mando_support_left_am_EAST","mando_support_left_am_GUER","mando_support_left_am_CIV","mando_support_left_ve_WEST", "mando_support_left_ve_EAST","mando_support_left_ve_GUER","mando_support_left_ve_CIV","mando_support_left_re_WEST", "mando_support_left_re_EAST","mando_support_left_re_GUER","mando_support_left_re_CIV","mando_support_left_cp_WEST", "mando_support_left_cp_EAST","mando_support_left_cp_GUER","mando_support_left_cp_CIV"];

   if (isNil "mando_airsupport_cmissile") then
   {
      mando_airsupport_cmissile = objNull;
      mando_airsupport_cmissile_pos = [0,0,0];
   };


   if (isNil "mando_airsupport_type") then
   {
      if (side player != east) then
      {
         mando_airsupport_type = "AV8B2";      
      }
      else
      {
         mando_airsupport_type = "Su34B";
      };
   };

   if (isNil "mando_airsupport_type_ca") then
   {
      if (side player != east) then
      {
         if (side player == resistance) then
         {
            mando_airsupport_type_ca = "AH6_RACS";
         }
         else
         {
            mando_airsupport_type_ca = "AH1W";
         };
      }
      else
      {
         mando_airsupport_type_ca = "KA50";
      };
   };

   if (isNil "mando_airsupport_type_pa") then
   {
      if (side player != east) then
      {
         if (side player == resistance) then
         {
            mando_airsupport_type_pa = "UH60MG";
         }
         else
         {
            mando_airsupport_type_pa = "UH60MG";
         };
      }
      else
      {
         mando_airsupport_type_pa = "Mi17_MG";
      };
   };

   if (isNil "mando_airsupport_type_rc") then
   {
      if (side player != east) then
      {
         if (side player == resistance) then
         {
            mando_airsupport_type_rc = "AV8B";
         }
         else
         {
            mando_airsupport_type_rc = "AV8B";
         };
      }
      else
      {
         mando_airsupport_type_rc = "Su34";
      };
   };


   if (isNil "mando_airsupport_type_cp") then
   {
      if (side player != east) then
      {
         if (side player == resistance) then
         {
            mando_airsupport_type_cp = "AV8B";
         }
         else
         {
            mando_airsupport_type_cp = "AV8B";
         };
      }
      else
      {
         mando_airsupport_type_cp = "Su34";
      };
   };


   if (isNil "mando_airsupport_type_am") then
   {
      if (side player != east) then
      {
         if (side player == resistance) then
         {
            mando_airsupport_type_am = "UH60MG";
         }
         else
         {
            mando_airsupport_type_am = "UH60MG";
         };
      }
      else
      {
         mando_airsupport_type_am = "Mi17_MG";
      };
   };

   if (isNil "mando_airsupport_type_ambox") then
   {
      if (side player != east) then
      {
         if (side player == resistance) then
         {
            mando_airsupport_type_ambox = "WeaponBoxGuer";
         }
         else
         {
            mando_airsupport_type_ambox = "WeaponBoxWest";
         };
      }
      else
      {
         mando_airsupport_type_ambox = "WeaponBoxEast";
      };
   };

   if (isNil "mando_airsupport_type_ve") then
   {
      if (side player != east) then
      {
         if (side player == resistance) then
         {
            mando_airsupport_type_ve = "UH60MG";
         }
         else
         {
            mando_airsupport_type_ve = "UH60MG";
         };
      }
      else
      {
         mando_airsupport_type_ve = "Mi17_MG";
      };
   };

   if (isNil "mando_airsupport_type_vehicle") then
   {
      if (side player != east) then
      {
         if (side player == resistance) then
         {
            mando_airsupport_type_vehicle = "Truck5t";
         }
         else
         {
            mando_airsupport_type_vehicle = "Truck5t";
         };
      }
      else
      {
         mando_airsupport_type_vehicle = "Ural";
      };
   };


   if (isNil "mando_support_infantrytype") then
   {
      switch (side player) do
      {
         case west:
         {
            mando_support_infantrytype = ["TeamLeaderW", "SoldierWMedic", "SoldierWAT","SoldierWB","SoldierWB","SoldierWB","SoldierWB","SoldierWB","SoldierWB","SoldierWB"];
         };

         case east:
         {
            mando_support_infantrytype = ["TeamLeaderE", "SoldierEMedic", "SoldierEAT","SoldierEB","SoldierEB","SoldierEB","SoldierEB","SoldierEB","SoldierEB","SoldierEB"];
         };

         case resistance:
         {
            mando_support_infantrytype = ["TeamLeaderG", "SoldierGMedic", "SoldierGAT","SoldierGB","SoldierGB","SoldierGB","SoldierGB","SoldierGB","SoldierGB","SoldierGB"];
         };

         case civilian:
         {
            mando_support_infantrytype = ["Civilian1", "Civilian2","Civilian3","Civilian4","Civilian5","Civilian6","Civilian7","Civilian8","Civilian9","Civilian10"];
         };
      };
   };


   if (isNil "mando_airsupport_range") then
   {
      mando_airsupport_range = 4500;
   } 
   else
   {
      if (mando_airsupport_range < 3500) then
      { 
         mando_airsupport_range = 3500;
      }; 
   };

   if (isNil "mando_airsupport_max_cas") then
   {
      mando_airsupport_max_cas = 2;
   };

   if (isNil "mando_airsupport_bomb_type") then
   {
      mando_airsupport_bomb_type = "Bo_GBU12_LGB";
   };

   if (isNil "mando_airsupport_bomb_alt") then
   {
      mando_airsupport_bomb_alt = 150;
   };

   if (isNil "mando_airsupportdlg") then
   {
      mando_airsupportdlg = compile (preprocessFileLineNumbers "mando_airsupportdlg.sqf");
   };

   if (isNil "mando_airsupport_bomb_pos") then
   {
      mando_airsupport_bomb_pos = [2, 0, -2];
   };

   if (isNil "mando_support_no_cas") then
   {
      mando_support_no_cas = false;
   };

   if (isNil "mando_support_no_br") then
   {
      mando_support_no_br = false;
   };

   if (isNil "mando_support_no_ff") then
   {
      mando_support_no_ff = false;
   };

   if (isNil "mando_support_no_sa") then
   {
      mando_support_no_sa = false;
   };

   if (isNil "mando_support_no_gs") then
   {
      mando_support_no_gs = false;
   };

   if (isNil "mando_support_no_ab") then
   {
      mando_support_no_ab = false;
   };

   if (isNil "mando_support_no_cm") then
   {
      mando_support_no_cm = false;
   };

   if (isNil "mando_support_no_rc") then
   {
      mando_support_no_rc = false;
   };

   if (isNil "mando_support_no_am") then
   {
      mando_support_no_am = false;
   };

   if (isNil "mando_support_no_ve") then
   {
      mando_support_no_ve = false;
   };

   if (isNil "mando_support_no_re") then
   {
      mando_support_no_re = false;
   };

   if (isNil "mando_support_no_cp") then
   {
      mando_support_no_cp = false;
   };

   mando_cam_scale = 1;
   Sleep 0.5;
   _ok = createDialog "MandoAirSupportDlg";
};

switch (_event) do
{
   case "onLoad":
   {
      _display = _params select 0;
      mando_support_display = _display;    

      _left = call compile format["mando_support_left_%1", side player];

      if (_left > 0) then
      {
         for [{_i=0},{_i< (_left min 4)},{_i=_i+1}] do
         {
            if (_i == 0) then
            {
               (_display displayCtrl 23901) lbAdd "Allocate 1 plane";
            }
            else
            {
               (_display displayCtrl 23901) lbAdd format["Allocate %1 planes", _i + 1];
            };
         };
         (_display displayCtrl 23901) lbSetCurSel 0;
      };      
      (_display displayCtrl 23902) ctrlSetText format["Aircrafts available: %1", _left];


      (_display displayCtrl 23920) sliderSetRange [-180, 180];
      (_display displayCtrl 23920) sliderSetSpeed [5, 20];
      (_display displayCtrl 23920) sliderSetPosition (0);
      mando_ingress_dir = sliderPosition (mando_support_display displayCtrl 23920);

      if ((mando_airsupport_bomb_alt < 100) || (mando_airsupport_bomb_alt > 300)) then
      {
         mando_airsupport_bomb_alt = 150;
      };

      (_display displayCtrl 23922) sliderSetRange [100, 300];
      (_display displayCtrl 23922) sliderSetSpeed [5, 20];
      (_display displayCtrl 23922) sliderSetPosition (mando_airsupport_bomb_alt);
      (_display displayCtrl 23921) ctrlSetText format["Ingress min alt: %1m", floor mando_airsupport_bomb_alt];


      if ((isNil "mando_missile_init") || ((call compile format["mando_support_left_cm_%1", side player]) < 1)) then
      {
         (_display displayCtrl 23917) ctrlEnable false;
      };

      (_display displayCtrl 23915) ctrlSetText format["GS (%1)", call compile format["mando_support_left_ca_%1", side player]];
      (_display displayCtrl 23916) ctrlSetText format["AB (%1)", call compile format["mando_support_left_pa_%1", side player]];
      (_display displayCtrl 23917) ctrlSetText format["CM (%1)", call compile format["mando_support_left_cm_%1", side player]];
      (_display displayCtrl 23923) ctrlSetText format["RC (%1)", call compile format["mando_support_left_rc_%1", side player]];
      (_display displayCtrl 23924) ctrlSetText format["AM (%1)", call compile format["mando_support_left_am_%1", side player]];
      (_display displayCtrl 23925) ctrlSetText format["VE (%1)", call compile format["mando_support_left_ve_%1", side player]];
      (_display displayCtrl 23926) ctrlSetText format["RE (%1)", call compile format["mando_support_left_re_%1", side player]];
      (_display displayCtrl 23927) ctrlSetText format["CP (%1)", call compile format["mando_support_left_cp_%1", side player]];

      if ((call compile format["mando_support_left_ca_%1", side player]) < 1) then
      {
         (_display displayCtrl 23915) ctrlEnable false;
      };

      if ((call compile format["mando_support_left_pa_%1", side player]) < 1) then
      {
         (_display displayCtrl 23916) ctrlEnable false;
      };

      if ((call compile format["mando_support_left_cm_%1", side player]) < 1) then
      {
         (_display displayCtrl 23917) ctrlEnable false;
      };

      if ((call compile format["mando_support_left_rc_%1", side player]) < 1) then
      {
         (_display displayCtrl 23923) ctrlEnable false;
      };

      if ((call compile format["mando_support_left_am_%1", side player]) < 1) then
      {
         (_display displayCtrl 23924) ctrlEnable false;
      };

      if ((call compile format["mando_support_left_ve_%1", side player]) < 1) then
      {
         (_display displayCtrl 23925) ctrlEnable false;
      };

      if ((call compile format["mando_support_left_re_%1", side player]) < 1) then
      {
         (_display displayCtrl 23926) ctrlEnable false;
      };

      if ((call compile format["mando_support_left_cp_%1", side player]) < 1) then
      {
         (_display displayCtrl 23927) ctrlEnable false;
      };


      if (mando_airsupport_bomb_type == "SADARM") then
      {
         (_display displayCtrl 23913) ctrlSetTextColor [0, 0, 0, 1];
         (_display displayCtrl 23914) ctrlSetTextColor [0, 1, 0, 1];
      }
      else
      {
         (_display displayCtrl 23913) ctrlSetTextColor [0, 1, 0, 1];
         (_display displayCtrl 23914) ctrlSetTextColor [0, 0, 0, 1];
      };

      (_display displayCtrl 23909) ctrlSetTooltip "Call for Close Air Support (fixed wing)";
      (_display displayCtrl 23910) ctrlSetTooltip "Call for Bomb Run (fixed wing)";
      (_display displayCtrl 23915) ctrlSetTooltip "Call for Gunships (attack choppers)";
      (_display displayCtrl 23916) ctrlSetTooltip "Call for airborne assault";
      (_display displayCtrl 23917) ctrlSetTooltip "Call for cruise missile attack";
      (_display displayCtrl 23923) ctrlSetTooltip "Call for reconnaissance";
      (_display displayCtrl 23924) ctrlSetTooltip "Call for ammo supply";
      (_display displayCtrl 23925) ctrlSetTooltip "Call for vehicle supply";
      (_display displayCtrl 23926) ctrlSetTooltip "Call for reinforcements";
      (_display displayCtrl 23927) ctrlSetTooltip "Call for Combat Air Patrol";


      if (mando_support_no_cas) then
      {
         (_display displayCtrl 23909) ctrlEnable false;   
      };

      if (mando_support_no_br) then
      {
         (_display displayCtrl 23910) ctrlEnable false;   
      };

      if (mando_support_no_ff) then
      {
         (_display displayCtrl 23913) ctrlEnable false;   
      };

      if (mando_support_no_sa) then
      {
         (_display displayCtrl 23914) ctrlEnable false;   
      };

      if (mando_support_no_gs) then
      {
         (_display displayCtrl 23915) ctrlEnable false;   
      };

      if (mando_support_no_ab) then
      {
         (_display displayCtrl 23916) ctrlEnable false;   
      };

      if (mando_support_no_cm) then
      {
         (_display displayCtrl 23917) ctrlEnable false;   
      };

      if (mando_support_no_rc) then
      {
         (_display displayCtrl 23923) ctrlEnable false;   
      };

      if (mando_support_no_am) then
      {
         (_display displayCtrl 23924) ctrlEnable false;   
      };

      if (mando_support_no_ve) then
      {
         (_display displayCtrl 23925) ctrlEnable false;   
      };

      if (mando_support_no_re) then
      {
         (_display displayCtrl 23926) ctrlEnable false;   
      };

      if (mando_support_no_cp) then
      {
         (_display displayCtrl 23927) ctrlEnable false;   
      };


      if (getMarkerColor "mk_mandoairsupport" == "") then
      {
         _marker = createMarkerLocal ["mk_mandoairsupport", [getPos vehicle player select 0, getPos vehicle player select 1]];
         "mk_mandoairsupport" setMarkerShapeLocal "ELLIPSE";
         "mk_mandoairsupport" setMarkerColorLocal "ColorGreenAlpha";
         "mk_mandoairsupport" setMarkerSizeLocal [500, 500];

         _marker = createMarkerLocal ["mk_mandoairsupport_dot", [getPos vehicle player select 0, getPos vehicle player select 1]];
         "mk_mandoairsupport_dot" setMarkerTypeLocal "Dot";
         "mk_mandoairsupport_dot" setMarkerColorLocal "ColorGreen";
         "mk_mandoairsupport_dot" setMarkerSizeLocal [0.25, 0.25];
         "mk_mandoairsupport_dot" setMarkerTextLocal "Support";

         _marker = createMarkerLocal ["mk_mandoairsupport_op", [getPos vehicle player select 0, getPos vehicle player select 1]];
         "mk_mandoairsupport_op" setMarkerTypeLocal "Arrow";
         "mk_mandoairsupport_op" setMarkerColorLocal "ColorGreen";
         "mk_mandoairsupport_op" setMarkerSizeLocal [0.5, 0.5];
         "mk_mandoairsupport_op" setMarkerTextLocal "Operator";
      };

      []spawn
      {
         private ["_cam", "_commdisplay", "_pos", "_posold", "_loglos", "_poslos", "_dirlos", "_i", "_dist", "_mando_cam_scale_old", "_mando_ingress_dir_old", "_angh", "_ratev", "_asl1", "_asl2"];

         showCinemaBorder false;
         _cam = "camera" camcreate [0, 0, 0];
         _cam cameraeffect ["internal", "back"];
         _cam camSetFov 1;
         _cam camCommit 0;
         _loglos = "logic" createVehicleLocal [0,0,0];

         _commdisplay = findDisplay 23900;
         _pos = [-1,-1];
         _posold = [-1,-1,-1];
         _mando_cam_scale_old = mando_cam_scale;
         _mando_ingress_dir_old = mando_ingress_dir;

         createMarkerLocal ["mando_ingress_dir", [0,0]];
         "mando_ingress_dir" setMarkerShapeLocal "RECTANGLE";
         "mando_ingress_dir" setMarkerColorLocal "ColorWhite";
         "mando_ingress_dir" setMarkerSizeLocal [2, 100];

         onMapSingleClick "true";
         while {!isNull _commdisplay} do
         {
            if (!alive player) then
            {
               CloseDialog 23900;
            };
            "mk_mandoairsupport_op" setMarkerPosLocal getPos vehicle player;
            "mk_mandoairsupport_op" setMarkerDirLocal getDir vehicle player;
            if (((_pos select 0) != (getMarkerPos "mk_mandoairsupport" select 0)) ||
                ((_pos select 1) != (getMarkerPos "mk_mandoairsupport" select 1)) ||
                ((getPos vehicle player select 0) != (_posold select 0)) ||
                ((getPos vehicle player select 1) != (_posold select 1)) ||
                ((getPos vehicle player select 2) != (_posold select 2)) ||
                (mando_cam_scale != _mando_cam_scale_old) ||
                (mando_ingress_dir != _mando_ingress_dir_old) ) then
            {
               _mando_ingress_dir_old = mando_ingress_dir;
               _mando_cam_scale_old = mando_cam_scale;
               _posold = getPos vehicle player;
               _pos = [getMarkerPos "mk_mandoairsupport" select 0, getMarkerPos "mk_mandoairsupport" select 1, 0];
               _loglos setPos _pos;
               _pos set [2, getPosASL _loglos select 2];

               _poslos = [getPosASL (vehicle player) select 0,getPosASL (vehicle player) select 1,(getPosASL (vehicle player) select 2)+2];

               _angh =  mando_ingress_dir;
               "mando_ingress_dir" setMarkerPosLocal [(_pos select 0)+sin(_angh)*750, (_pos select 1)+cos(_angh)*750];
               "mando_ingress_dir" setMarkerDirLocal _angh;
               "mando_ingress_dir" setMarkerSizeLocal [6, 500/2];

                (mando_support_display displayCtrl 23911) ctrlSetText format["Ingress direction: %1 deg", floor mando_ingress_dir];

               _loglos setPosASL _poslos;
               _loglos setDir 0;

               _dist = 0.001 + sqrt(((_poslos select 0) - (_pos select 0))^2 + ((_poslos select 1) - (_pos select 1))^2);

               if (_dist < 2000) then
               {
                  _dirlos = ((_pos select 0)-(_poslos select 0)) atan2 ((_pos select 1)-(_poslos select 1));                   
                  _ratev = ((_pos select 2) - (_poslos select 2))/_dist;


                  for [{_i = 20},{_i < (_dist - 25)},{_i=_i + 25}] do
                  {
                     _loglos setPosASL [(_poslos select 0)+sin(_dirlos)*_i,(_poslos select 1)+cos(_dirlos)*_i, (_poslos select 2)+_ratev*_i];

                     if ((getPos _loglos select 2) <= 0) then
                     {             
                        _i = 9999; 
                     };
                  };

                  if (_i < 9999) then
                  {
                     _loglos setPos [(_pos select 0)-230*mando_cam_scale, (_pos select 1)+160*mando_cam_scale, 0];
                     _asl1 = getPosASL _loglos select 2;
                     _loglos setPos [(_pos select 0), (_pos select 1), 0];
                     _asl2 = getPosASL _loglos select 2;

                     _cam camSetPos [(_pos select 0)-230*mando_cam_scale, (_pos select 1)+160*mando_cam_scale, 300*mando_cam_scale + (_asl2 - _asl1)];
                     _cam camSetTarget [(_pos select 0)-230*mando_cam_scale, (_pos select 1) + (160*mando_cam_scale) + 1, (_asl2 - _asl1)];

                     _cam camCommit 0;
                  
                     (_commdisplay displayCtrl 23904) ctrlSetBackgroundColor [0, 0.2, 0, 0];
                     (_commdisplay displayCtrl 23904) ctrlSetTextColor [0, 1, 0, 0];
                  }
                  else
                  {
                     (_commdisplay displayCtrl 23904) ctrlSetBackgroundColor [0, 0.2, 0, 1];
                     (_commdisplay displayCtrl 23904) ctrlSetTextColor [0, 1, 0, 1];
                  };
               }
               else
               {
                  (_commdisplay displayCtrl 23904) ctrlSetBackgroundColor [0, 0.2, 0, 1];
                  (_commdisplay displayCtrl 23904) ctrlSetTextColor [0, 1, 0, 1];
               };
            };
            Sleep 0.1;
         };
         _cam cameraeffect ["terminate", "back"];
         camDestroy _cam;
         deleteVehicle _loglos;
         deleteMarkerLocal "mk_mandoairsupport";
         deleteMarkerLocal "mk_mandoairsupport_dot";
         deleteMarkerLocal "mk_mandoairsupport_op";
         deleteMarkerLocal "mando_ingress_dir";
         onMapSingleClick "";
      };

      []spawn
      {
         private ["_commdisplay", "_left", "_leftold", "_i", "_left_ca", "_leftold_ca", "_left_pa", "_leftold_pa", "_left_cm", "_leftold_cm", "_left_rc", "_leftold_rc", "_left_am", "_leftold_am", "_left_ve", "_leftold_ve", "_left_re", "_leftold_re", "_left_cp", "_leftold_cp"];
         _commdisplay = findDisplay 23900;
         _left = call compile format["mando_support_left_%1", side player];
         _leftold = _left;

         _left_ca = call compile format["mando_support_ca_left_%1", side player];
         _leftold_ca = _left_ca;

         _left_pa = call compile format["mando_support_pa_left_%1", side player];
         _leftold_pa = _left_pa;

         _left_cm = call compile format["mando_support_cm_left_%1", side player];
         _leftold_cm = _left_cm;

         _left_rc = call compile format["mando_support_rc_left_%1", side player];
         _leftold_rc = _left_rc;

         _left_am = call compile format["mando_support_am_left_%1", side player];
         _leftold_am = _left_am;

         _left_ve = call compile format["mando_support_ve_left_%1", side player];
         _leftold_ve = _left_ve;

         _left_re = call compile format["mando_support_re_left_%1", side player];
         _leftold_re = _left_re;

         _left_cp = call compile format["mando_support_cp_left_%1", side player];
         _leftold_cp = _left_cp;


         while {!isNull _commdisplay} do
         {
            _left = call compile format["mando_support_left_%1", side player];
            if (_left != _leftold) then
            { 
               _leftold = _left;
               Sleep 0.5;
               _left = _left - lbSize (mando_support_display displayCtrl 23901);
               if (_left < 0) then
               {
                  for [{_i=0},{_i < abs(_left)},{_i=_i+1}] do
                  {
                     (mando_support_display displayCtrl 23901) lbDelete (lbSize (mando_support_display displayCtrl 23901)-1);
                  };
                  (mando_support_display displayCtrl 23901) lbSetCurSel 0;
               };
               (mando_support_display displayCtrl 23902) ctrlSetText format["Aircrafts available: %1", call compile format["mando_support_left_%1", side player]];
            };
            _left_ca = call compile format["mando_support_ca_left_%1", side player];
            if (_left_ca != _leftold_ca) then
            {
               _leftold_ca = _left_ca;
               (_display displayCtrl 23915) ctrlSetText format["GS (%1)", _left_ca];
            };       

            _left_pa = call compile format["mando_support_pa_left_%1", side player];
            if (_left_pa != _leftold_pa) then
            {
               _leftold_pa = _left_pa;
               (_display displayCtrl 23916) ctrlSetText format["AB (%1)", _left_pa];
            };       

            _left_cm = call compile format["mando_support_cm_left_%1", side player];
            if (_left_cm != _leftold_cm) then
            {
               _leftold_cm = _left_cm;
               (_display displayCtrl 23917) ctrlSetText format["CM (%1)", _left_cm];
            };       

            _left_rc = call compile format["mando_support_rc_left_%1", side player];
            if (_left_rc != _leftold_rc) then
            {
               _leftold_rc = _left_rc;
               (_display displayCtrl 23923) ctrlSetText format["RC (%1)", _left_rc];
            };       

            _left_am = call compile format["mando_support_am_left_%1", side player];
            if (_left_am != _leftold_am) then
            {
               _leftold_am = _left_am;
               (_display displayCtrl 23924) ctrlSetText format["AM (%1)", _left_am];
            };       

            _left_ve = call compile format["mando_support_ve_left_%1", side player];
            if (_left_ve != _leftold_ve) then
            {
               _leftold_ve = _left_ve;
               (_display displayCtrl 23925) ctrlSetText format["VE (%1)", _left_am];
            };       

            _left_re = call compile format["mando_support_re_left_%1", side player];
            if (_left_re != _leftold_re) then
            {
               _leftold_re = _left_re;
               (_display displayCtrl 23926) ctrlSetText format["RE (%1)", _left_am];
            };       

            _left_cp = call compile format["mando_support_cp_left_%1", side player];
            if (_left_cp != _leftold_cp) then
            {
               _leftold_cp = _left_cp;
               (_display displayCtrl 23927) ctrlSetText format["CP (%1)", _left_am];
            };       


            Sleep 1;
         };
      };
   };

   case "onMapClick":
   {
      if (((_this select 1) select 1) == 0) then
      {
         "mk_mandoairsupport" setMarkerPosLocal (((_this select 1) select 0) ctrlMapScreenToWorld [(_this select 1) select 2, (_this select 1) select 3]);
         "mk_mandoairsupport" setMarkerSizeLocal [500, 500];

         "mk_mandoairsupport_dot" setMarkerPosLocal (((_this select 1) select 0) ctrlMapScreenToWorld [(_this select 1) select 2, (_this select 1) select 3]) ;
         "mk_mandoairsupport_dot" setMarkerSizeLocal [0.25,0.25];
      };
   };


   case "CALL_BOMB_RUN":
   {
      _left = call compile format["mando_support_left_%1", side player];
      if (_left > 0) then
      {
         _nplanes = 1 + lbCurSel (mando_support_display displayCtrl 23901);
         if (side player == west) then
         { 
            mando_support_left_WEST = mando_support_left_WEST - _nplanes;
            publicVariable "mando_support_left_WEST";
         }
         else
         {
            if (side player == east) then
            { 
               mando_support_left_EAST = mando_support_left_EAST - _nplanes;
               publicVariable "mando_support_left_EAST";
            }
            else
            {
               if (side player == resistance) then
               { 
                  mando_support_left_GUER = mando_support_left_GUER - _nplanes;
                  publicVariable "mando_support_left_GUER";
               }
               else
               {
                  mando_support_left_CIV = mando_support_left_CIV - _nplanes;
                  publicVariable "mando_support_left_CIV";
               };
            };
         };
   
         _left = call compile format["mando_support_left_%1", side player];

         _left = _left - lbSize (mando_support_display displayCtrl 23901);
         if (_left < 0) then
         {
            for [{_i=0},{_i < abs(_left)},{_i=_i+1}] do
            {
               (mando_support_display displayCtrl 23901) lbDelete (lbSize (mando_support_display displayCtrl 23901)-1);
            };
            (mando_support_display displayCtrl 23901) lbSetCurSel 0;
         };
         (mando_support_display displayCtrl 23902) ctrlSetText format["Aircrafts available: %1", call compile format["mando_support_left_%1", side player]];

         (mando_support_display displayCtrl 23909) ctrlEnable false;
         (mando_support_display displayCtrl 23910) ctrlEnable false;
         (mando_support_display displayCtrl 23912) ctrlSetText "Bomb run mission in progress";


         for [{_i=0},{_i < _nplanes},{_i = _i + 1}] do
         {
            [_i] spawn
            {
               private["_plane", "_targetpos", "_spawnpos", "_group", "_driver", "_ang", "_scr", "_logasl", "_speed", "_extrah"];

               _ang = random 359;
               _targetpos = [(getMarkerPos "mk_mandoairsupport" select 0)+sin(_ang)*10*(_this select 0),(getMarkerPos "mk_mandoairsupport" select 1)+cos(_ang)*10*(_this select 0)];
               _logasl = "logic" createVehicleLocal [0,0,0];
               _logasl setPos [_targetpos select 0, _targetpos select 1, 0];

               _ang = mando_ingress_dir;

               _spawnpos = [(_targetpos select 0) + sin(_ang)*(mando_airsupport_range+(_this select 0)*200), (_targetpos select 1) + cos(_ang)*(mando_airsupport_range+(_this select 0)*200)];
               _plane = createVehicle [mando_airsupport_type, _spawnpos, [], 0, "FLY"];
               _speed = speed _plane;

               _group = createGroup (side player);
               _driver = _group createUnit ["SoldierWPilot",[0,0,30], [], 0, "FORM"];
               _driver setskill 0.5;
               _driver setCombatMode "BLUE";
               _driver setBehaviour "CARELESS";
               _driver moveInDriver _plane;
               _group selectLeader _driver;

               if (!isNil "mando_missile_init") then
               {
                  _plane SetVehicleInit "res = [This] execVM ""mando_missiles\units\mando_onlymandoones.sqf""";
                  [_plane, 800, 1, 5, false, 0]execVM"mando_missiles\units\mando_missileecm.sqf";
                  processInitCommands;
               };

               Sleep 0.1;

               _ang = ((_targetpos select 0)-(_spawnpos select 0)) atan2 ((_targetpos select 1)-(_spawnpos select 1));
               if ((getPosASL _plane select 2) < ((getPosASL _logasl select 2) + mando_airsupport_bomb_alt)) then
               {
                  _plane setPosASL [_spawnpos select 0,_spawnpos select 1, (getPosASL _logasl select 2) + mando_airsupport_bomb_alt];
                  _extrah = (getPosASL _logasl select 2);
               };
               _plane setDir _ang;
               _plane setVelocity [sin(_ang)*_speed/3.6,cos(_ang)*_speed/3.6,0];
               deleteVehicle _logasl;


               [_this select 0, _plane] spawn
               {
                  private ["_base", "_plane"];
                  _plane = _this select 1;
                  _base = floor (random 1000);      
                  _marker = createMarkerLocal [format["mk_mandoairsupport_p%1", _base], [getPos _plane select 0, getPos _plane select 1]];
                  format["mk_mandoairsupport_p%1", _base] setMarkerTypeLocal "Arrow";
                  format["mk_mandoairsupport_p%1", _base] setMarkerColorLocal "ColorGreen";
                  format["mk_mandoairsupport_p%1", _base] setMarkerSizeLocal [0.5, 0.5];
                  format["mk_mandoairsupport_p%1", _base] setMarkerTextLocal format["Plane%1", (_this select 0)+1];

                  while {alive _plane} do
                  {
                     format["mk_mandoairsupport_p%1", _base] setMarkerPosLocal getPos (_this select 1);
                     format["mk_mandoairsupport_p%1", _base] setMarkerDirLocal getDir (_this select 1);
                     Sleep 0.5;
                  };
                  deleteMarkerLocal format["mk_mandoairsupport_p%1", _base];
               };

               _scr = [_plane, _targetpos, false, mando_airsupport_bomb_pos, _extrah + mando_airsupport_bomb_alt+(_this select 0)*10,mando_airsupport_bomb_type]execVM"mando_bombs.sqf";
           
               while {!scriptDone _scr} do
               {
                  Sleep 0.5;
                  (mando_support_display displayCtrl (23905 + (_this select 0))) ctrlSetText format["Plane %1: %2", (_this select 0)+1, (_plane getVariable "mando_airsupport_state")];
               };
               _plane doMove _spawnpos;
               Sleep 3;
               (mando_support_display displayCtrl (23905 + (_this select 0))) ctrlSetText format["Plane %1: ----", (_this select 0)+1];
               Sleep 60;
               if (alive _plane) then
               {
                  deleteVehicle _plane;
                  deleteVehicle _driver;
                  deleteGroup _group;
               };
            };
         };


         [] spawn
         {
            Sleep 3;
            while {("Plane 1: ----" != ctrlText (mando_support_display displayCtrl 23905)) ||
                   ("Plane 2: ----" != ctrlText (mando_support_display displayCtrl 23906)) ||
                   ("Plane 3: ----" != ctrlText (mando_support_display displayCtrl 23907)) ||
                   ("Plane 4: ----" != ctrlText (mando_support_display displayCtrl 23908))} do
            {
               Sleep 1;
            };
            (mando_support_display displayCtrl 23909) ctrlEnable true;
            (mando_support_display displayCtrl 23910) ctrlEnable true;
            (mando_support_display displayCtrl 23912) ctrlSetText "";
         };
      }
      else
      {
         (mando_support_display displayCtrl 23902) ctrlSetText "No planes left!";
      };
   };


   case "CALL_CAS":
   {
      _left = call compile format["mando_support_left_%1", side player];
      if (_left > 0) then
      {
         _nplanes = 1 + lbCurSel (mando_support_display displayCtrl 23901);
         if (side player == west) then
         { 
            mando_support_left_WEST = mando_support_left_WEST - _nplanes;
            publicVariable "mando_support_left_WEST";
         }
         else
         {
            if (side player == east) then
            { 
               mando_support_left_EAST = mando_support_left_EAST - _nplanes;
               publicVariable "mando_support_left_EAST";
            }
            else
            {
               if (side player == resistance) then
               { 
                  mando_support_left_GUER = mando_support_left_GUER - _nplanes;
                  publicVariable "mando_support_left_GUER";
               }
               else
               {
                  mando_support_left_CIV = mando_support_left_CIV - _nplanes;
                  publicVariable "mando_support_left_CIV";
               };
            };
         };
   
         _left = call compile format["mando_support_left_%1", side player];

         _left = _left - lbSize (mando_support_display displayCtrl 23901);
         if (_left < 0) then
         {
            for [{_i=0},{_i < abs(_left)},{_i=_i+1}] do
            {
               (mando_support_display displayCtrl 23901) lbDelete (lbSize (mando_support_display displayCtrl 23901)-1);
            };
            (mando_support_display displayCtrl 23901) lbSetCurSel 0;
         };
         (mando_support_display displayCtrl 23902) ctrlSetText format["Aircrafts available: %1", call compile format["mando_support_left_%1", side player]];

         (mando_support_display displayCtrl 23909) ctrlEnable false;
         (mando_support_display displayCtrl 23910) ctrlEnable false;
         (mando_support_display displayCtrl 23912) ctrlSetText "CAS mission in progress";

         for [{_i=0},{_i < _nplanes},{_i = _i + 1}] do
         {
            [_i] spawn
            {
               private["_plane", "_targetpos", "_spawnpos", "_group", "_driver", "_ang", "_scr", "_list1", "_list2", "_ntarget", "_target", "_cas", "_logasl", "_speed", "_extrah"];

               _cas = 0;
               _list1 = nearestObjects [getMarkerPos "mk_mandoairsupport", ["Car","Tank", "StaticWeapon", "Ship"], 500];
               _list2 = []; 
               {
                  if ((side _x != side player) && (alive _x) && ((count crew _x)>0)) then
                  { 
                     _list2 = _list2 + [_x];
                  };
               } forEach _list1;

               if (count _list2 > 0) then
               {
                  _ntarget = random (count _list2);
                  _ntarget = floor _ntarget;
                  _target = _list2 select _ntarget;
                  _targetpos = getPos _target;
                  _logasl = "logic" createVehicleLocal [0,0,0];
                  _logasl setPos [_targetpos select 0, _targetpos select 1, 0];

                  _ang = mando_ingress_dir;
                  _spawnpos = [(_targetpos select 0) + sin(_ang)*(mando_airsupport_range+(_this select 0)*200), (_targetpos select 1) + cos(_ang)*(mando_airsupport_range+(_this select 0)*200)];
                  _plane = createVehicle [mando_airsupport_type, _spawnpos, [], 0, "FLY"];
                  _speed = speed _plane;
                  _ang = ((_targetpos select 0)-(_spawnpos select 0)) atan2 ((_targetpos select 1)-(_spawnpos select 1));
                  if ((getPosASL _plane select 2) < ((getPosASL _logasl select 2) + mando_airsupport_bomb_alt)) then
                  {
                     _plane setPosASL [_spawnpos select 0,_spawnpos select 1, (getPosASL _logasl select 2) + mando_airsupport_bomb_alt + (_this select 0)*15];
                     _extrah = (getPosASL _logasl select 2);
                  };

                  _plane setDir _ang;
                  _plane setVelocity [sin(_ang)*_speed/3.6,cos(_ang)*_speed/3.6,0]; 
                   deleteVehicle _logasl;

                  _group = createGroup (side player);
                  _driver = _group createUnit ["SoldierWPilot",[0,0,30], [], 0, "NONE"];
                  _driver setskill 0.5;
                  _driver setCombatMode "BLUE";
                  _driver setBehaviour "CARELESS";
                  _driver moveInDriver _plane;
                  _group selectLeader _driver;

                  if (!isNil "mando_missile_init") then
                  {
                     _plane SetVehicleInit "res = [This] execVM ""mando_missiles\units\mando_onlymandoones.sqf""";
                     [_plane, 800, 1, 5, false, 0]execVM"mando_missiles\units\mando_missileecm.sqf";
                     processInitCommands;
                  };

                  Sleep 1;
                  [_this select 0, _plane] spawn
                  {
                     private ["_base", "_plane"];
                     _plane = _this select 1;
                     _base = floor (random 1000);      
                     _marker = createMarkerLocal [format["mk_mandoairsupport_p%1", _base], [getPos _plane select 0, getPos _plane select 1]];
                     format["mk_mandoairsupport_p%1", _base] setMarkerTypeLocal "Arrow";
                     format["mk_mandoairsupport_p%1", _base] setMarkerColorLocal "ColorGreen";
                     format["mk_mandoairsupport_p%1", _base] setMarkerSizeLocal [0.5, 0.5];
                     format["mk_mandoairsupport_p%1", _base] setMarkerTextLocal format["Plane%1", (_this select 0)+1];
   
                     while {alive _plane} do
                     {
                        format["mk_mandoairsupport_p%1", _base] setMarkerPosLocal getPos (_this select 1);
                        format["mk_mandoairsupport_p%1", _base] setMarkerDirLocal getDir (_this select 1);
                        Sleep 0.5;
                     };
                     deleteMarkerLocal format["mk_mandoairsupport_p%1", _base];
                  };


                  while {(count _list2 > 0) && (alive _plane)} do
                  {
                     _scr = [_plane, _target, false, mando_airsupport_bomb_pos, _extrah + mando_airsupport_bomb_alt+(_this select 0)*15,mando_airsupport_bomb_type]execVM"mando_bombs.sqf";
           
                     while {!scriptDone _scr} do
                     {
                        Sleep 0.5;
                        (mando_support_display displayCtrl (23905 + (_this select 0))) ctrlSetText format["Plane %1: %2", (_this select 0)+1, (_plane getVariable "mando_airsupport_state")];
                        (mando_support_display displayCtrl 23909) ctrlEnable false;
                        (mando_support_display displayCtrl 23910) ctrlEnable false;
                        (mando_support_display displayCtrl 23912) ctrlSetText "CAS mission in progress";
                     };
                     Sleep 6;

                     _list2 = [];
                     _cas = _cas + 1;                     
                     if (_cas < mando_airsupport_max_cas) then
                     {
                        {
                           if ((side _x != side player) && (alive _x)) then
                           { 
                              _list2 = _list2 + [_x];
                           };
                        } forEach _list1;
      
                        if (count _list2 > 0) then
                        {
                           _ntarget = random (count _list2);
                           _ntarget = floor _ntarget;
                           _target = _list2 select _ntarget;
                        };
                     };
                  };
                  _plane doMove _spawnpos;
                  Sleep 15;
                  if (alive _plane) then
                  {
                     deleteVehicle _plane;
                     deleteVehicle _driver;
                     deleteGroup _group;
                  };
                  (mando_support_display displayCtrl (23905 + (_this select 0))) ctrlSetText format["Plane %1: ----", (_this select 0)+1];
               }
               else
               {
                  (mando_support_display displayCtrl 23912) ctrlSetText "No targets for CAS mission";
               };
            };
         };

         [] spawn
         {
            Sleep 3;
            while {("Plane 1: ----" != ctrlText (mando_support_display displayCtrl 23905)) ||
                   ("Plane 2: ----" != ctrlText (mando_support_display displayCtrl 23906)) ||
                   ("Plane 3: ----" != ctrlText (mando_support_display displayCtrl 23907)) ||
                   ("Plane 4: ----" != ctrlText (mando_support_display displayCtrl 23908))} do
            {
               Sleep 1;
            };
            (mando_support_display displayCtrl 23909) ctrlEnable true;
            (mando_support_display displayCtrl 23910) ctrlEnable true;
            (mando_support_display displayCtrl 23912) ctrlSetText "";
         };
      }
      else
      {
         (mando_support_display displayCtrl 23902) ctrlSetText "No planes left!";
      };
   };


   case "CALL_CAS_CA":
   {
      (mando_support_display displayCtrl 23915) ctrlEnable false;
      _left = call compile format["mando_support_left_ca_%1", side player];
      if (_left > 0) then
      {
         if (side player == west) then
         { 
            mando_support_left_ca_WEST = mando_support_left_ca_WEST - 1;
            publicVariable "mando_support_left_ca_WEST";
         }
         else
         {
            if (side player == east) then
            { 
               mando_support_left_ca_EAST = mando_support_left_ca_EAST - 1;
               publicVariable "mando_support_left_ca_EAST";
            }
            else
            {
               if (side player == resistance) then
               { 
                  mando_support_left_ca_GUER = mando_support_left_ca_GUER - 1;
                  publicVariable "mando_support_left_ca_GUER";
               }
               else
               {
                  mando_support_left_ca_CIV = mando_support_left_ca_CIV - 1;
                  publicVariable "mando_support_left_ca_CIV";
               };
            };
         };
   
         _left = call compile format["mando_support_left_ca_%1", side player];
         if (_left > 0) then
         {
            []spawn
            {
               Sleep 4;
               (mando_support_display displayCtrl 23915) ctrlEnable true;
            };
         };
         (mando_support_display displayCtrl 23915) ctrlSetText format["GS (%1)", _left];

         [_left] spawn
         {
            private["_left", "_plane", "_targetpos", "_spawnpos", "_group", "_driver", "_ang", "_i", "_utype", "_speed"];
            _left = _this select 0;
            _targetpos = getMarkerPos "mk_mandoairsupport";
            _group = createGroup (side player);

            switch (side player) do
            {
               case west:
               {
                  _utype = "SoldierWPilot";
               };
               case east:
               {
                  _utype = "SoldierEPilot";
               };
               case resistance:
               {
                  _utype = "SoldierGPilot";
               };
               case civilian:
               {
                  _utype = "Civilian2";
               };
            };

            for [{_i = 0},{_i < 2},{_i=_i+1}] do
            {
               _ang = mando_ingress_dir;
               _spawnpos = [(_targetpos select 0) + sin(_ang)*(mando_airsupport_range+_i*50), (_targetpos select 1) + cos(_ang)*(mando_airsupport_range+_i*50)];

               _plane = createVehicle [mando_airsupport_type_ca, _spawnpos, [], 0, "FLY"];
               _speed = speed _plane;   
               _ang = ((_targetpos select 0)-(_spawnpos select 0)) atan2 ((_targetpos select 1)-(_spawnpos select 1));
               _plane setPos [_spawnpos select 0,_spawnpos select 1, mando_airsupport_bomb_alt max 100];
               _plane setDir _ang;
               _plane setVelocity [sin(_ang)*_speed/3.6,cos(_ang)*_speed/3.6,0]; 


               _driver = _group createUnit [_utype,[0,0,30], [], 0, "FORM"];
               _driver setskill 0.5;
               _driver setCombatMode "RED";
               _driver setBehaviour "AWARE";
               if (_i == 0) then
               {
                  _driver setRank "CORPORAL";
                  _group selectLeader _driver;
               }
               else
               {
                  _driver setRank "PRIVATE";
               };
               _driver moveInDriver _plane;
               _gunner = _group createUnit [_utype,[0,0,30], [], 0, "FORM"];
               _gunner setCombatMode "RED";
               _gunner setBehaviour "AWARE";
               _gunner setRank "PRIVATE";
               _gunner moveInGunner _plane;
               if (!(_gunner in _plane)) then
               {
                  deleteVehicle _gunner;
               };
               _plane flyinHeight mando_airsupport_bomb_alt max 100;
               if (!isNil "mando_missile_init") then
               {
                  _plane SetVehicleInit "res = [This] execVM ""mando_missiles\units\mando_onlymandoones.sqf""";
                  [_plane, 800, 1, 5, false, 0]execVM"mando_missiles\units\mando_missileecm.sqf";
                  processInitCommands;
               };
            };
            _wp = _group addWaypoint [_targetpos, 0];
            [_group, 1] showWaypoint "NEVER";
            [_group, 1] setWaypointSpeed "FULL";
            [_group, 1] setWaypointType "SAD";


            [_plane, _left] spawn
            { 
               private["_plane", "_left", "_marker", "_group"];
               _group = group driver (_this select 0);
               _plane = vehicle leader _group;
               _left = _this select 1;
               _marker = createMarkerLocal [format["mk_mando_ca_%1", _left], [getPos _plane select 0, getPos _plane select 1]];
               format["mk_mando_ca_%1", _left] setMarkerTypeLocal "Arrow";
               format["mk_mando_ca_%1", _left] setMarkerColorLocal "ColorGreen";
               format["mk_mando_ca_%1", _left] setMarkerSizeLocal [0.5, 0.5];
               format["mk_mando_ca_%1", _left] setMarkerTextLocal "GS";
               while {alive _plane} do
               {
                  _plane = vehicle leader _group; 
                  format["mk_mando_ca_%1", _left] setMarkerDirLocal getDir _plane;
                  format["mk_mando_ca_%1", _left] setMarkerPosLocal getPos _plane;
                  Sleep 1;
               };
               deleteMarkerLocal format["mk_mando_ca_%1", _left];
            };


            Sleep 4;
            waitUntil {((unitReady leader _group) && (alive leader _group)) || (!alive leader _group)};

            _group move _spawnpos;
            Sleep 4;

            waitUntil {((unitReady leader _group) && (alive leader _group)) || (!alive leader _group)};

            {
               if (alive vehicle _x) then
               {
                  deleteVehicle vehicle _x;
               };
            } forEach units _group;

            {
               if (alive _x) then
               {
                  deleteVehicle _x;
               };
            } forEach units _group;

            deleteGroup _group;
         };
      };
   };



   case "CALL_PARAS":
   {
      (mando_support_display displayCtrl 23916) ctrlEnable false;
      _left = call compile format["mando_support_left_pa_%1", side player];
      if (_left > 0) then
      {
         if (side player == west) then
         { 
            mando_support_left_pa_WEST = mando_support_left_pa_WEST - 1;
            publicVariable "mando_support_left_pa_WEST";
         }
         else
         {
            if (side player == east) then
            { 
               mando_support_left_pa_EAST = mando_support_left_pa_EAST - 1;
               publicVariable "mando_support_left_pa_EAST";
            }
            else
            {
               if (side player == resistance) then
               { 
                  mando_support_left_pa_GUER = mando_support_left_pa_GUER - 1;
                  publicVariable "mando_support_left_pa_GUER";
               }
               else
               {
                  mando_support_left_pa_CIV = mando_support_left_pa_CIV - 1;
                  publicVariable "mando_support_left_pa_CIV";
               };
            };
         };
   
         _left = call compile format["mando_support_left_pa_%1", side player];
         if (_left > 0) then
         {
            []spawn
            {
               Sleep 4;
               (mando_support_display displayCtrl 23916) ctrlEnable true;
            };
         };
         (mando_support_display displayCtrl 23916) ctrlSetText format["AB (%1)", _left];

         [_left] spawn
         {
            private["_left", "_plane", "_targetpos", "_spawnpos", "_group", "_group_i", "_driver", "_ang", "_i", "_utype", "_unit", "_speed"];
            _left = _this select 0;  
            _targetpos = getMarkerPos "mk_mandoairsupport";
            _group = createGroup (side player);

            switch (side player) do
            {
               case west:
               {
                  _utype = "SoldierWPilot";
               };
               case east:
               {
                  _utype = "SoldierEPilot";
               };
               case resistance:
               {
                  _utype = "SoldierGPilot";
               };
               case civilian:
               {
                  _utype = "Civilian2";
               };
            };

            _ang = mando_ingress_dir;
            _spawnpos = [(_targetpos select 0) + sin(_ang)*mando_airsupport_range, (_targetpos select 1) + cos(_ang)*mando_airsupport_range];

            _plane = createVehicle [mando_airsupport_type_pa, _spawnpos, [], 0, "FLY"];
            _speed = speed _plane;
            _ang = ((_targetpos select 0)-(_spawnpos select 0)) atan2 ((_targetpos select 1)-(_spawnpos select 1));
            _plane setPos [_spawnpos select 0,_spawnpos select 1, mando_airsupport_bomb_alt max 100];
            _plane setDir _ang;
            _plane setVelocity [sin(_ang)*_speed/3.6,cos(_ang)*_speed/3.6,0]; 


            _driver = _group createUnit [_utype,[0,0,30], [], 0, "FORM"];
            _driver setskill 0.5;
            _driver setCombatMode "BLUE";
            _driver setBehaviour "CARELESS";
            _driver setRank "CORPORAL";
            _group selectLeader _driver;
            _driver moveInDriver _plane;
            _plane flyinHeight mando_airsupport_bomb_alt max 100;

            if (!isNil "mando_missile_init") then
            {
               _plane SetVehicleInit "res = [This] execVM ""mando_missiles\units\mando_onlymandoones.sqf""";
               [_plane, 800, 1, 5, false, 0]execVM"mando_missiles\units\mando_missileecm.sqf";
               processInitCommands;
            };

            [_plane, _left] spawn
            { 
               private["_plane", "_left", "_marker"];
               _plane = _this select 0;
               _left = _this select 1;
               _marker = createMarkerLocal [format["mk_mando_pa_%1", _left], [getPos _plane select 0, getPos _plane select 1]];
               format["mk_mando_pa_%1", _left] setMarkerTypeLocal "Arrow";
               format["mk_mando_pa_%1", _left] setMarkerColorLocal "ColorGreen";
               format["mk_mando_pa_%1", _left] setMarkerSizeLocal [0.5, 0.5];
               format["mk_mando_pa_%1", _left] setMarkerTextLocal "AB";
               while {alive _plane} do
               {
                  format["mk_mando_pa_%1", _left] setMarkerDirLocal getDir _plane;
                  format["mk_mando_pa_%1", _left] setMarkerPosLocal getPos _plane;
                  Sleep 1;
               };
               deleteMarkerLocal format["mk_mando_pa_%1", _left];
            };

            _wp = _group addWaypoint [_targetpos, 0];
            [_group, 1] showWaypoint "NEVER";
            [_group, 1] setWaypointSpeed "FULL";
            [_group, 1] setWaypointType "MOVE";

            _group_i = createGroup (side player);
            for [{_i = 0},{_i < 10},{_i=_i+1}] do
            {
               if (_i == 0) then
               {
                  _unit = _group_i createUnit [mando_support_infantrytype select _i,[0,0,30], [], 0, "NONE"];
                  _unit setCombatMode "RED";
                  _unit setBehaviour "AWARE";
                  _unit setRank "CORPORAL";
                  _group_i selectLeader _unit;
               }
               else
               {
                  _unit = _group_i createUnit [mando_support_infantrytype select _i,[0,0,30], [], 0, "NONE"];
                  _unit setCombatMode "RED";
                  _unit setBehaviour "AWARE";
                  _unit setRank "PRIVATE";
               };

               if (side player == civilian) then
               {
                  _unit addMagazine "30Rnd_545x39_AK";
                  _unit addMagazine "30Rnd_545x39_AK";
                  _unit addMagazine "30Rnd_545x39_AK";
                  _unit addWeapon "AK74";
               };

               _unit setskill 0.5;
               _unit moveInCargo _plane;
               _wp = _group_i addWaypoint [_targetpos, 0];
               [_group_i, 1] showWaypoint "NEVER";
               [_group_i, 1] setWaypointType "SAD";
               _wp = _group_i addWaypoint [_targetpos, 0];
               [_group_i, 2] showWaypoint "NEVER";
               [_group_i, 2] setWaypointType "HOLD";
            };

            Sleep 4;
            waitUntil {((unitReady leader _group) && (alive leader _group)) || (!alive leader _group)};
            if (alive _plane) then
            {
               {
                  _x action ["EJECT", vehicle _x];
                  unassignVehicle _x;
                  Sleep 0.75;
               } forEach units _group_i;
            };     
            Sleep 2;
            _group move _spawnpos;
            Sleep 4;

            waitUntil {((unitReady leader _group) && (alive leader _group)) || (!alive leader _group)};

            {
               if (alive vehicle _x) then
               {
                  deleteVehicle vehicle _x;
               };
            } forEach units _group;

            {
               if (alive _x) then
               {
                  deleteVehicle _x;
               };
            } forEach units _group;

            deleteGroup _group;
         };
      };
   };


   case "CALL_REINF":
   {
      (mando_support_display displayCtrl 23926) ctrlEnable false;
      _left = call compile format["mando_support_left_re_%1", side player];
      if (_left > 0) then
      {
         if (side player == west) then
         { 
            mando_support_left_re_WEST = mando_support_left_re_WEST - 1;
            publicVariable "mando_support_left_re_WEST";
         }
         else
         {
            if (side player == east) then
            { 
               mando_support_left_re_EAST = mando_support_left_re_EAST - 1;
               publicVariable "mando_support_left_re_EAST";
            }
            else
            {
               if (side player == resistance) then
               { 
                  mando_support_left_re_GUER = mando_support_left_re_GUER - 1;
                  publicVariable "mando_support_left_re_GUER";
               }
               else
               {
                  mando_support_left_re_CIV = mando_support_left_re_CIV - 1;
                  publicVariable "mando_support_left_re_CIV";
               };
            };
         };
   
         _left = call compile format["mando_support_left_re_%1", side player];
         if (_left > 0) then
         {
            []spawn
            {
               Sleep 4;
               (mando_support_display displayCtrl 23926) ctrlEnable true;
            };
         };
         (mando_support_display displayCtrl 23926) ctrlSetText format["RE (%1)", _left];

         [_left] spawn
         {
            private["_left", "_plane", "_targetpos", "_spawnpos", "_group", "_group_i", "_driver", "_ang", "_i", "_utype", "_unit", "_speed"];
            _left = _this select 0;  
            _targetpos = getMarkerPos "mk_mandoairsupport";
            _group = createGroup (side player);

            switch (side player) do
            {
               case west:
               {
                  _utype = "SoldierWPilot";
               };
               case east:
               {
                  _utype = "SoldierEPilot";
               };
               case resistance:
               {
                  _utype = "SoldierGPilot";
               };
               case civilian:
               {
                  _utype = "Civilian2";
               };
            };

            _ang = mando_ingress_dir;
            _spawnpos = [(_targetpos select 0) + sin(_ang)*mando_airsupport_range, (_targetpos select 1) + cos(_ang)*mando_airsupport_range];

            _plane = createVehicle [mando_airsupport_type_pa, _spawnpos, [], 0, "FLY"];
            _speed = speed _plane;
            _ang = ((_targetpos select 0)-(_spawnpos select 0)) atan2 ((_targetpos select 1)-(_spawnpos select 1));
            _plane setPos [_spawnpos select 0,_spawnpos select 1, mando_airsupport_bomb_alt max 100];
            _plane setDir _ang;
            _plane setVelocity [sin(_ang)*_speed/3.6,cos(_ang)*_speed/3.6,0]; 


            _driver = _group createUnit [_utype,[0,0,30], [], 0, "FORM"];
            _driver setskill 0.5;
            _driver setCombatMode "BLUE";
            _driver setBehaviour "CARELESS";
            _driver setRank "CORPORAL";
            _group selectLeader _driver;
            _driver moveInDriver _plane;
            _plane flyinHeight mando_airsupport_bomb_alt max 100;

            if (!isNil "mando_missile_init") then
            {
               _plane SetVehicleInit "res = [This] execVM ""mando_missiles\units\mando_onlymandoones.sqf""";
               [_plane, 800, 1, 5, false, 0]execVM"mando_missiles\units\mando_missileecm.sqf";
               processInitCommands;
            };

            [_plane, _left] spawn
            { 
               private["_plane", "_left", "_marker"];
               _plane = _this select 0;
               _left = _this select 1;
               _marker = createMarkerLocal [format["mk_mando_re_%1", _left], [getPos _plane select 0, getPos _plane select 1]];
               format["mk_mando_re_%1", _left] setMarkerTypeLocal "Arrow";
               format["mk_mando_re_%1", _left] setMarkerColorLocal "ColorGreen";
               format["mk_mando_re_%1", _left] setMarkerSizeLocal [0.5, 0.5];
               format["mk_mando_re_%1", _left] setMarkerTextLocal "RE";
               while {alive _plane} do
               {
                  format["mk_mando_re_%1", _left] setMarkerDirLocal getDir _plane;
                  format["mk_mando_re_%1", _left] setMarkerPosLocal getPos _plane;
                  Sleep 1;
               };
               deleteMarkerLocal format["mk_mando_re_%1", _left];
            };

            _wp = _group addWaypoint [_targetpos, 0];
            [_group, 1] showWaypoint "NEVER";
            [_group, 1] setWaypointSpeed "FULL";
            [_group, 1] setWaypointType "MOVE";

            _group_i = createGroup (side player);
            for [{_i = 0},{_i < 10},{_i=_i+1}] do
            {
               if (_i == 0) then
               {
                  _unit = _group_i createUnit [mando_support_infantrytype select _i,[0,0,30], [], 0, "NONE"];
                  _unit setCombatMode "RED";
                  _unit setBehaviour "AWARE";
                  _unit setRank "CORPORAL";
                  _group_i selectLeader _unit;
               }
               else
               {
                  _unit = _group_i createUnit [mando_support_infantrytype select _i,[0,0,30], [], 0, "NONE"];
                  _unit setCombatMode "RED";
                  _unit setBehaviour "AWARE";
                  _unit setRank "PRIVATE";
               };

               if (side player == civilian) then
               {
                  _unit addMagazine "30Rnd_545x39_AK";
                  _unit addMagazine "30Rnd_545x39_AK";
                  _unit addMagazine "30Rnd_545x39_AK";
                  _unit addWeapon "AK74";
               };

               _unit setskill 0.5;
               _unit moveInCargo _plane;
               _wp = _group_i addWaypoint [_targetpos, 0];
               [_group_i, 1] showWaypoint "NEVER";
               [_group_i, 1] setWaypointType "MOVE";
            };

            Sleep 4;
            waitUntil {((unitReady leader _group) && (alive leader _group)) || (!alive leader _group)};
            if (alive _plane) then
            {
               {
                  _x action ["EJECT", vehicle _x];
                  unassignVehicle _x;
                  Sleep 0.75;
               } forEach units _group_i;
            };     
            Sleep 2;
            _group move _spawnpos;
            Sleep 4;

            (units _group_i) join group player;

            waitUntil {((unitReady leader _group) && (alive leader _group)) || (!alive leader _group)};

            {
               if (alive vehicle _x) then
               {
                  deleteVehicle vehicle _x;
               };
            } forEach units _group;

            {
               if (alive _x) then
               {
                  deleteVehicle _x;
               };
            } forEach units _group;

            deleteGroup _group;
         };
      };
   };



   case "CALL_RECO":
   {
      (mando_support_display displayCtrl 23923) ctrlEnable false;
      _left = call compile format["mando_support_left_rc_%1", side player];
      if (_left > 0) then
      {
         if (side player == west) then
         { 
            mando_support_left_rc_WEST = mando_support_left_rc_WEST - 1;
            publicVariable "mando_support_left_rc_WEST";
         }
         else
         {
            if (side player == east) then
            { 
               mando_support_left_rc_EAST = mando_support_left_rc_EAST - 1;
               publicVariable "mando_support_left_rc_EAST";
            }
            else
            {
               if (side player == resistance) then
               { 
                  mando_support_left_rc_GUER = mando_support_left_rc_GUER - 1;
                  publicVariable "mando_support_left_rc_GUER";
               }
               else
               {
                  mando_support_left_rc_CIV = mando_support_left_rc_CIV - 1;
                  publicVariable "mando_support_left_rc_CIV";
               };
            };
         };
   
         _left = call compile format["mando_support_left_rc_%1", side player];
         if (_left > 0) then
         {
            []spawn
            {
               Sleep 4;
               (mando_support_display displayCtrl 23923) ctrlEnable true;
            };
         };
         (mando_support_display displayCtrl 23923) ctrlSetText format["RC (%1)", _left];

         [_left] spawn
         {
            private["_left", "_plane", "_targetpos", "_spawnpos", "_group", "_driver", "_ang", "_i", "_utype", "_unit", "_speed"];
            _left = _this select 0;  
            _targetpos = getMarkerPos "mk_mandoairsupport";
            _group = createGroup (side player);

            switch (side player) do
            {
               case west:
               {
                  _utype = "SoldierWPilot";
               };
               case east:
               {
                  _utype = "SoldierEPilot";
               };
               case resistance:
               {
                  _utype = "SoldierGPilot";
               };
               case civilian:
               {
                  _utype = "Civilian2";
               };
            };

            _ang = mando_ingress_dir;
            _spawnpos = [(_targetpos select 0) + sin(_ang)*mando_airsupport_range, (_targetpos select 1) + cos(_ang)*mando_airsupport_range];

            _plane = createVehicle [mando_airsupport_type_rc, _spawnpos, [], 0, "FLY"];
            _speed = speed _plane;
            _ang = ((_targetpos select 0)-(_spawnpos select 0)) atan2 ((_targetpos select 1)-(_spawnpos select 1));
            _plane setPos [_spawnpos select 0,_spawnpos select 1, mando_airsupport_bomb_alt max 100];
            _plane setDir _ang;
            _plane setVelocity [sin(_ang)*_speed/3.6,cos(_ang)*_speed/3.6,0]; 


            _driver = _group createUnit [_utype,[0,0,30], [], 0, "FORM"];
            _driver setskill 0.5;
            _driver setCombatMode "BLUE";
            _driver setBehaviour "CARELESS";
            _driver setRank "CORPORAL";
            _group selectLeader _driver;
            _driver moveInDriver _plane;
            _plane flyinHeight mando_airsupport_bomb_alt max 100;

            if (!isNil "mando_missile_init") then
            {
               _plane SetVehicleInit "res = [This] execVM ""mando_missiles\units\mando_onlymandoones.sqf""";
               [_plane, 800, 1, 5, false, 0]execVM"mando_missiles\units\mando_missileecm.sqf";
               processInitCommands;
            };

            [_plane, _left] spawn
            { 
               private["_plane", "_left", "_marker"];
               _plane = _this select 0;
               _left = _this select 1;
               _marker = createMarkerLocal [format["mk_mando_rc_%1", _left], [getPos _plane select 0, getPos _plane select 1]];
               format["mk_mando_rc_%1", _left] setMarkerTypeLocal "Arrow";
               format["mk_mando_rc_%1", _left] setMarkerColorLocal "ColorGreen";
               format["mk_mando_rc_%1", _left] setMarkerSizeLocal [0.5, 0.5];
               format["mk_mando_rc_%1", _left] setMarkerTextLocal "RC";
               while {alive _plane} do
               {
                  format["mk_mando_rc_%1", _left] setMarkerDirLocal getDir _plane;
                  format["mk_mando_rc_%1", _left] setMarkerPosLocal getPos _plane;
                  Sleep 1;
               };
               deleteMarkerLocal format["mk_mando_rc_%1", _left];
            };

            _wp = _group addWaypoint [_targetpos, 0];
            [_group, 1] showWaypoint "NEVER";
            [_group, 1] setWaypointSpeed "FULL";
            [_group, 1] setWaypointType "MOVE";
            _wp = _group addWaypoint [[(_targetpos select 0)+sin(mando_ingress_dir)*4000,(_targetpos select 1)+cos(mando_ingress_dir)*4000], 0];
            [_group, 2] showWaypoint "NEVER";
            [_group, 2] setWaypointSpeed "FULL";
            [_group, 2] setWaypointType "MOVE";

            [_plane] spawn
            {
               private ["_plane", "_targets", "_array", "_i", "_base"];
               _plane = _this select 0;
               _targets = [];
               while {alive _plane} do
               {
                  _array = nearestObjects [[getPos _plane select 0,getPos _plane select 1,0], ["LandVehicle","Ship"], 400];
                  {
                     if (!(_x in _targets) && (_x != _plane) && (side _x != side _plane) && (alive _x)) then
                     {
                        _targets = _targets + [_x];
                     };
                  } forEach _array;
                  Sleep 1;
               };
               (mando_support_display displayCtrl 23912) ctrlSetText "Receiving reconnaissance data";

               []spawn
               {
                  private["_trigger"];
                  _trigger = createTrigger ["EmptyDetector", [0, 0, 0]];
                  _trigger setTriggerActivation ["NONE", "PRESENT", false];
                  _trigger setTriggerArea [0, 0, 0, false];
                  _trigger setTriggerType "NONE";
                  _trigger setTriggerTimeout [0, 0, 0, false ];
                  _trigger setTriggerStatements ["true", "res = [true]execVM""mando_airsupportdlg.sqf""", ""];
                  Sleep 6;
                  deleteVehicle _trigger;
               };
               

               Sleep 2;
               _base = random 200;
               _base = floor _base;
               _i = 0;
               {
                  _marker = createMarker [format["mk_mando_rct_%1", _i + _base], getPos _x];
                  format["mk_mando_rct_%1", _i + _base] setMarkerType "Empty";
                  format["mk_mando_rct_%1", _i + _base] setMarkerColor "ColorWhite";
                  format["mk_mando_rct_%1", _i + _base] setMarkerSize [0.25, 0.25];
                  format["mk_mando_rct_%1", _i + _base] setMarkerText typeOf _x;
                  _i = _i + 1;
                  Sleep 0.25;
               } forEach _targets;
               (mando_support_display displayCtrl 23912) ctrlSetText "reco data available for 2 mins";
               Sleep 2;


               mando_reco_side = side player;
               mando_reco_base = _base; 
               mando_reco_num = count _targets;
               publicVariable "mando_reco_side";
               publicVariable "mando_reco_base";
               publicVariable "mando_reco_num";
               Sleep 120;
               _i = 0;
               {
                  deleteMarker format["mk_mando_rct_%1", _i + _base];
                  _i = _i + 1;
               } forEach _targets;
               (mando_support_display displayCtrl 23912) ctrlSetText "Reconnaissance data cleared";
            };


            Sleep 4;
            waitUntil {((unitReady leader _group) && (alive leader _group)) || (!alive leader _group)};
            Sleep 4;
            waitUntil {((unitReady leader _group) && (alive leader _group)) || (!alive leader _group)};


            {
               if (alive vehicle _x) then
               {
                  deleteVehicle vehicle _x;
               };
            } forEach units _group;

            {
               if (alive _x) then
               {
                  deleteVehicle _x;
               };
            } forEach units _group;

            deleteGroup _group;
         };
      };
   };



   case "CALL_AMMO":
   {
      (mando_support_display displayCtrl 23924) ctrlEnable false;
      _left = call compile format["mando_support_left_am_%1", side player];
      if (_left > 0) then
      {
         if (side player == west) then
         { 
            mando_support_left_am_WEST = mando_support_left_am_WEST - 1;
            publicVariable "mando_support_left_am_WEST";
         }
         else
         {
            if (side player == east) then
            { 
               mando_support_left_am_EAST = mando_support_left_am_EAST - 1;
               publicVariable "mando_support_left_am_EAST";
            }
            else
            {
               if (side player == resistance) then
               { 
                  mando_support_left_am_GUER = mando_support_left_am_GUER - 1;
                  publicVariable "mando_support_left_am_GUER";
               }
               else
               {
                  mando_support_left_am_CIV = mando_support_left_am_CIV - 1;
                  publicVariable "mando_support_left_am_CIV";
               };
            };
         };
   
         _left = call compile format["mando_support_left_am_%1", side player];
         if (_left > 0) then
         {
            []spawn
            {
               Sleep 4;
               (mando_support_display displayCtrl 23924) ctrlEnable true;
            };
         };
         (mando_support_display displayCtrl 23924) ctrlSetText format["AM (%1)", _left];

         [_left] spawn
         {
            private["_left", "_plane", "_targetpos", "_spawnpos", "_group", "_driver", "_ang", "_i", "_utype", "_unit", "_speed"];
            _left = _this select 0;  
            _targetpos = getMarkerPos "mk_mandoairsupport";
            _group = createGroup (side player);

            switch (side player) do
            {
               case west:
               {
                  _utype = "SoldierWPilot";
               };
               case east:
               {
                  _utype = "SoldierEPilot";
               };
               case resistance:
               {
                  _utype = "SoldierGPilot";
               };
               case civilian:
               {
                  _utype = "Civilian2";
               };
            };

            _ang = mando_ingress_dir;
            _spawnpos = [(_targetpos select 0) + sin(_ang)*mando_airsupport_range, (_targetpos select 1) + cos(_ang)*mando_airsupport_range];

            _plane = createVehicle [mando_airsupport_type_am, _spawnpos, [], 0, "FLY"];
            _speed = speed _plane;
            _ang = ((_targetpos select 0)-(_spawnpos select 0)) atan2 ((_targetpos select 1)-(_spawnpos select 1));
            _plane setPos [_spawnpos select 0,_spawnpos select 1, mando_airsupport_bomb_alt max 100];
            _plane setDir _ang;
            _plane setVelocity [sin(_ang)*_speed/3.6,cos(_ang)*_speed/3.6,0]; 


            _driver = _group createUnit [_utype,[0,0,30], [], 0, "FORM"];
            _driver setskill 0.5;
            _driver setCombatMode "BLUE";
            _driver setBehaviour "CARELESS";
            _driver setRank "CORPORAL";
            _group selectLeader _driver;
            _driver moveInDriver _plane;
            _plane flyinHeight mando_airsupport_bomb_alt max 100;

            if (!isNil "mando_missile_init") then
            {
               _plane SetVehicleInit "res = [This] execVM ""mando_missiles\units\mando_onlymandoones.sqf""";
               [_plane, 800, 1, 5, false, 0]execVM"mando_missiles\units\mando_missileecm.sqf";
               processInitCommands;
            };

            [_plane, _left] spawn
            { 
               private["_plane", "_left", "_marker"];
               _plane = _this select 0;
               _left = _this select 1;
               _marker = createMarkerLocal [format["mk_mando_am_%1", _left], [getPos _plane select 0, getPos _plane select 1]];
               format["mk_mando_am_%1", _left] setMarkerTypeLocal "Arrow";
               format["mk_mando_am_%1", _left] setMarkerColorLocal "ColorGreen";
               format["mk_mando_am_%1", _left] setMarkerSizeLocal [0.5, 0.5];
               format["mk_mando_am_%1", _left] setMarkerTextLocal "AM";
               while {alive _plane} do
               {
                  format["mk_mando_am_%1", _left] setMarkerDirLocal getDir _plane;
                  format["mk_mando_am_%1", _left] setMarkerPosLocal getPos _plane;
                  Sleep 1;
               };
               deleteMarkerLocal format["mk_mando_am_%1", _left];
            };

            _wp = _group addWaypoint [_targetpos, 0];
            [_group, 1] showWaypoint "NEVER";
            [_group, 1] setWaypointSpeed "FULL";
            [_group, 1] setWaypointType "MOVE";


            Sleep 4;
            waitUntil {((unitReady leader _group) && (alive leader _group)) || (!alive leader _group)};
            if (alive _plane) then
            {
               for [{_i=0},{_i < 2},{_i = _i + 1}] do
               { 
                  [_plane]spawn
                  {
                     private["_plane", "_para", "_box", "_pos"];
                     _plane = _this select 0;

                     _pos  = _plane modelToWorld [0,-6, 0];
                     _para = "ParachuteWest" createVehicle [0,0,0];
                     _para setPos _pos;
                     _box = mando_airsupport_type_ambox createVehicle [0,0,0];
                     while {(getPos _para select 2) > 2.5} do 
                     {
                        _box setPos (_para modelToWorld [0,0,-2]);
                        _box setVectorDir (vectorDir _para);
                        _box setVectorUp (vectorUp _para);
                        Sleep 0.002;
                     };
                     _box setDir 0;
                     _box setPos [getPos _para select 0, getPos _para select 1, 0];
                  };
                  Sleep 3;
               };
            };

            _group move _spawnpos;
            Sleep 4;

            waitUntil {((unitReady leader _group) && (alive leader _group)) || (!alive leader _group)};

            {
               if (alive vehicle _x) then
               {
                  deleteVehicle vehicle _x;
               };
            } forEach units _group;

            {
               if (alive _x) then
               {
                  deleteVehicle _x;
               };
            } forEach units _group;

            deleteGroup _group;
         };
      };
   };


   case "CALL_VEH":
   {
      (mando_support_display displayCtrl 23925) ctrlEnable false;
      _left = call compile format["mando_support_left_ve_%1", side player];
      if (_left > 0) then
      {
         if (side player == west) then
         { 
            mando_support_left_ve_WEST = mando_support_left_ve_WEST - 1;
            publicVariable "mando_support_left_ve_WEST";
         }
         else
         {
            if (side player == east) then
            { 
               mando_support_left_ve_EAST = mando_support_left_ve_EAST - 1;
               publicVariable "mando_support_left_ve_EAST";
            }
            else
            {
               if (side player == resistance) then
               { 
                  mando_support_left_ve_GUER = mando_support_left_ve_GUER - 1;
                  publicVariable "mando_support_left_ve_GUER";
               }
               else
               {
                  mando_support_left_ve_CIV = mando_support_left_ve_CIV - 1;
                  publicVariable "mando_support_left_ve_CIV";
               };
            };
         };
   
         _left = call compile format["mando_support_left_ve_%1", side player];
         if (_left > 0) then
         {
            []spawn
            {
               Sleep 4;
               (mando_support_display displayCtrl 23925) ctrlEnable true;
            };
         };
         (mando_support_display displayCtrl 23925) ctrlSetText format["VE (%1)", _left];

         [_left] spawn
         {
            private["_left", "_plane", "_targetpos", "_spawnpos", "_group", "_driver", "_ang", "_i", "_utype", "_unit", "_speed", "_truck"];
            _left = _this select 0;  
            _targetpos = getMarkerPos "mk_mandoairsupport";
            _group = createGroup (side player);

            switch (side player) do
            {
               case west:
               {
                  _utype = "SoldierWPilot";
               };
               case east:
               {
                  _utype = "SoldierEPilot";
               };
               case resistance:
               {
                  _utype = "SoldierGPilot";
               };
               case civilian:
               {
                  _utype = "Civilian2";
               };
            };

            _ang = mando_ingress_dir;
            _spawnpos = [(_targetpos select 0) + sin(_ang)*mando_airsupport_range, (_targetpos select 1) + cos(_ang)*mando_airsupport_range];

            _plane = createVehicle [mando_airsupport_type_ve, _spawnpos, [], 0, "FLY"];
            _speed = speed _plane;
            _ang = ((_targetpos select 0)-(_spawnpos select 0)) atan2 ((_targetpos select 1)-(_spawnpos select 1));
            _plane setPos [_spawnpos select 0,_spawnpos select 1, mando_airsupport_bomb_alt max 100];
            _plane setDir _ang;
            _plane setVelocity [sin(_ang)*_speed/3.6,cos(_ang)*_speed/3.6,0]; 

            _driver = _group createUnit [_utype,[0,0,30], [], 0, "FORM"];
            _driver setskill 0.5;
            _driver setCombatMode "BLUE";
            _driver setBehaviour "CARELESS";
            _driver setRank "CORPORAL";
            _group selectLeader _driver;
            _driver moveInDriver _plane;
            _plane flyinHeight mando_airsupport_bomb_alt max 100;

            if (!isNil "mando_missile_init") then
            {
               _plane SetVehicleInit "res = [This] execVM ""mando_missiles\units\mando_onlymandoones.sqf""";
               [_plane, 800, 1, 5, false, 0]execVM"mando_missiles\units\mando_missileecm.sqf";
               processInitCommands;
            };

            [_plane, _left] spawn
            { 
               private["_plane", "_left", "_marker"];
               _plane = _this select 0;
               _left = _this select 1;
               _marker = createMarkerLocal [format["mk_mando_ve_%1", _left], [getPos _plane select 0, getPos _plane select 1]];
               format["mk_mando_ve_%1", _left] setMarkerTypeLocal "Arrow";
               format["mk_mando_ve_%1", _left] setMarkerColorLocal "ColorGreen";
               format["mk_mando_ve_%1", _left] setMarkerSizeLocal [0.5, 0.5];
               format["mk_mando_ve_%1", _left] setMarkerTextLocal "VE";
               while {alive _plane} do
               {
                  format["mk_mando_ve_%1", _left] setMarkerDirLocal getDir _plane;
                  format["mk_mando_ve_%1", _left] setMarkerPosLocal getPos _plane;
                  Sleep 1;
               };
               deleteMarkerLocal format["mk_mando_ve_%1", _left];
            };

            _wp = _group addWaypoint [_targetpos, 0];
            [_group, 1] showWaypoint "NEVER";
            [_group, 1] setWaypointSpeed "FULL";
            [_group, 1] setWaypointType "MOVE";
            Sleep 4;
            _truck = mando_airsupport_type_vehicle createVehicle [0,0,0];
            while {(alive _plane) && !(unitReady leader _group)} do
            {
               _truck setPos (_plane modelToWorld [0,0,-10]);
               _truck setVectorDir (vectorDir _plane);
               _truck setVectorUp (vectorUP _plane);
               Sleep 0.002;
            };
            if (alive _plane) then
            {
               _plane flyinHeight 10;
               _plane doMove [getPos _plane select 0,getPos _plane select 1, 10];

               while {(alive _plane) && ((getPos _plane select 2) > 12)} do
               {
                  _truck setPos (_plane modelToWorld [0,0,-8]);
                  _truck setVectorDir (vectorDir _plane);
                  _truck setVectorUp (vectorUP _plane);
                  Sleep 0.002;
               };
            };
            _plane flyinHeight 100;
            _group move _spawnpos;
            Sleep 4;

            waitUntil {((unitReady leader _group) && (alive leader _group)) || (!alive leader _group)};

            {
               if (alive vehicle _x) then
               {
                  deleteVehicle vehicle _x;
               };
            } forEach units _group;

            {
               if (alive _x) then
               {
                  deleteVehicle _x;
               };
            } forEach units _group;

            deleteGroup _group;
         };
      };
   };


   case "CALL_CAP":
   {
      (mando_support_display displayCtrl 23927) ctrlEnable false;
      _left = call compile format["mando_support_left_cp_%1", side player];
      if (_left > 0) then
      {
         if (side player == west) then
         { 
            mando_support_left_cp_WEST = mando_support_left_cp_WEST - 1;
            publicVariable "mando_support_left_cp_WEST";
         }
         else
         {
            if (side player == east) then
            { 
               mando_support_left_cp_EAST = mando_support_left_cp_EAST - 1;
               publicVariable "mando_support_left_cp_EAST";
            }
            else
            {
               if (side player == resistance) then
               { 
                  mando_support_left_cp_GUER = mando_support_left_cp_GUER - 1;
                  publicVariable "mando_support_left_cp_GUER";
               }
               else
               {
                  mando_support_left_cp_CIV = mando_support_left_cp_CIV - 1;
                  publicVariable "mando_support_left_cp_CIV";
               };
            };
         };
   
         _left = call compile format["mando_support_left_cp_%1", side player];
         if (_left > 0) then
         {
            []spawn
            {
               Sleep 4;
               (mando_support_display displayCtrl 23927) ctrlEnable true;
            };
         };
         (mando_support_display displayCtrl 23927) ctrlSetText format["CP (%1)", _left];

         [_left] spawn
         {
            private["_left", "_plane", "_targetpos", "_spawnpos", "_group", "_driver", "_ang", "_i", "_utype", "_speed"];
            _left = _this select 0;
            _targetpos = getMarkerPos "mk_mandoairsupport";
            _group = createGroup (side player);

            switch (side player) do
            {
               case west:
               {
                  _utype = "SoldierWPilot";
               };
               case east:
               {
                  _utype = "SoldierEPilot";
               };
               case resistance:
               {
                  _utype = "SoldierGPilot";
               };
               case civilian:
               {
                  _utype = "Civilian2";
               };
            };

            for [{_i = 0},{_i < 2},{_i=_i+1}] do
            {
               _ang = mando_ingress_dir;
               _spawnpos = [(_targetpos select 0) + sin(_ang)*(mando_airsupport_range+_i*50), (_targetpos select 1) + cos(_ang)*(mando_airsupport_range+_i*50)];

               _plane = createVehicle [mando_airsupport_type_cp, _spawnpos, [], 0, "FLY"];
               _speed = speed _plane;
               _ang = ((_targetpos select 0)-(_spawnpos select 0)) atan2 ((_targetpos select 1)-(_spawnpos select 1));
               _plane setPos [_spawnpos select 0,_spawnpos select 1, mando_airsupport_bomb_alt max 100];
               _plane setDir _ang;
               _plane setVelocity [sin(_ang)*_speed/3.6,cos(_ang)*_speed/3.6,0]; 

               _driver = _group createUnit [_utype,[0,0,30], [], 0, "FORM"];
               _driver setskill 0.5;
               _driver setCombatMode "RED";
               _driver setBehaviour "AWARE";
               if (_i == 0) then
               {
                  _driver setRank "CORPORAL";
                  _group selectLeader _driver;
               }
               else
               {
                  _driver setRank "PRIVATE";
               };
               _driver moveInDriver _plane;
               _plane flyinHeight mando_airsupport_bomb_alt max 100;
               if (!isNil "mando_missile_init") then
               {
                  _plane SetVehicleInit "res = [This] execVM ""mando_missiles\units\mando_onlymandoones.sqf""";
                  [_plane, 800, 1, 5, false, 0]execVM"mando_missiles\units\mando_missileecm.sqf";
                  processInitCommands;
               };
            };
            _wp = _group addWaypoint [_targetpos, 0];
            [_group, 1] showWaypoint "NEVER";
            [_group, 1] setWaypointSpeed "FULL";
            [_group, 1] setWaypointType "HOLD";


            [_plane, _left] spawn
            { 
               private["_plane", "_left", "_marker", "_group"];
               _group = group driver (_this select 0);
               _plane = vehicle leader _group;
               _left = _this select 1;
               _marker = createMarkerLocal [format["mk_mando_cp_%1", _left], [getPos _plane select 0, getPos _plane select 1]];
               format["mk_mando_cp_%1", _left] setMarkerTypeLocal "Arrow";
               format["mk_mando_cp_%1", _left] setMarkerColorLocal "ColorGreen";
               format["mk_mando_cp_%1", _left] setMarkerSizeLocal [0.5, 0.5];
               format["mk_mando_cp_%1", _left] setMarkerTextLocal "CP";
               while {alive _plane} do
               {
                  format["mk_mando_cp_%1", _left] setMarkerDirLocal getDir _plane;
                  format["mk_mando_cp_%1", _left] setMarkerPosLocal getPos _plane;
                  Sleep 1;
               };
               deleteMarkerLocal format["mk_mando_cp_%1", _left];
            };
         };
      };
   };



   case "CALL_CRUISEMISSILE":
   {
      (mando_support_display displayCtrl 23917) ctrlEnable false;
      _left = call compile format["mando_support_left_cm_%1", side player];

      if (!alive mando_airsupport_cmissile) then 
      {
         _left = 0;
         (mando_support_display displayCtrl 23912) ctrlSetText "Cruise missile launcher not present";
      };

      if (_left > 0) then
      {
         if (side player == west) then
         { 
            mando_support_left_cm_WEST = mando_support_left_cm_WEST - 1;
            publicVariable "mando_support_left_cm_WEST";
         }
         else
         {
            if (side player == east) then
            { 
               mando_support_left_cm_EAST = mando_support_left_cm_EAST - 1;
               publicVariable "mando_support_left_cm_EAST";
            }
            else
            {
               if (side player == resistance) then
               { 
                  mando_support_left_cm_GUER = mando_support_left_cm_GUER - 1;
                  publicVariable "mando_support_left_cm_GUER";
               }
               else
               {
                  mando_support_left_cm_CIV = mando_support_left_cm_CIV - 1;
                  publicVariable "mando_support_left_cm_CIV";
               };
            };
         };
   
         _left = call compile format["mando_support_left_cm_%1", side player];
         if (_left > 0) then
         {
            []spawn
            {
               Sleep 4;
               (mando_support_display displayCtrl 23917) ctrlEnable true;
            };

            [] spawn
            {
               private ["_target", "_dir"];
               _target = "logic" createVehicleLocal [0,0,0];

               _target setPos [getMarkerPos "mk_mandoairsupport" select 0, getMarkerPos "mk_mandoairsupport" select 1, 0];

               _dir = ((getPos _target select 0)-(getPos mando_airsupport_cmissile select 0)) atan2 ((getPos _target select 1)-(getPos mando_airsupport_cmissile select 1));

               [mando_airsupport_cmissile, "Bo_GBU12_LGB", mando_airsupport_cmissile_pos, _dir, 89, 0, 300, 100, _target, 5, 2000, 0, 800, "mando_missiles\warheads\mando_missilehead2a.sqf", "mando_missiles\exhausts\mando_missilesmoke1a.sqf", "mando_missile1", 29, 50, true, 5, 0, 0, true, false, "mando_missiles\launch\mando_scudlaunch.sqf", 25, 35, 1, true, 180, 180] execVM "mando_missiles\mando_missile.sqf";

               Sleep 60;
               deleteVehicle _target;


            };
         };
         (mando_support_display displayCtrl 23917) ctrlSetText format["CM (%1)", _left];
      };

   };

   case "ZOOM_IN":
   {
      if (mando_cam_scale > 0.2) then
      {
         mando_cam_scale = mando_cam_scale - 0.1;
      };
   };

   case "ZOOM_OUT":
   {
      if (mando_cam_scale < 1) then
      {
         mando_cam_scale = mando_cam_scale + 0.1;
      };
   };

   case "INGRESS_CHANGE":
   {
      mando_ingress_dir = sliderPosition (mando_support_display displayCtrl 23920);
   };

   case "INGRESS_ALT_CHANGE":
   {
      mando_airsupport_bomb_alt = sliderPosition (mando_support_display displayCtrl 23922);
      (mando_support_display displayCtrl 23921) ctrlSetText format["Ingress min alt: %1m", floor mando_airsupport_bomb_alt];
   };


   case "FREE_FALL":
   {
      (mando_support_display displayCtrl 23913) ctrlSetTextColor [0, 1, 0, 1];
      (mando_support_display displayCtrl 23914) ctrlSetTextColor [0, 0, 0, 1];
      mando_airsupport_bomb_type = "Bo_GBU12_LGB";
   };

   case "SADARM":
   {
      (mando_support_display displayCtrl 23913) ctrlSetTextColor [0, 0, 0, 1];
      (mando_support_display displayCtrl 23914) ctrlSetTextColor [0, 1, 0, 1];
      mando_airsupport_bomb_type = "SADARM";
   };


   default {};
};

true